## Running the GraphQL Pagination Example Project

This guide will walk you through the steps to run the GraphQL Pagination Example project.

### Prerequisites

Make sure you have the following software installed on your machine:

- Node.js (v16 or higher)
- NPM (Node Package Manager)

### Step 1: Install Dependencies

1. Navigate to the project directory:

```bash
cd graphql-pagination
```

2. Install the project dependencies using the following command:

```bash
npm install
```

This will install the required packages specified in the `package.json` file.

### Step 2: Start the Server

1. In the project directory, run the following command to start the server:

```bash
node index.js
```

The server will start running on `http://localhost:9444/graphql`. You should see a message in the console indicating that the server is running.

### Step 3: Accessing GraphiQL

1. Open a web browser.
2. Visit `http://localhost:9444/graphql`.

This will open the GraphiQL interface, a tool for testing GraphQL queries.

### Step 4: Execute GraphQL Queries

1. In the GraphiQL interface, you can write and execute GraphQL queries.
2. Here are some sample queries you can try:

   - Get all users:

   ```graphql
   query {
     users {
       totalCount
       edges {
         node {
           id
           name
           email
         }
         cursor
       }
       pageInfo {
         endCursor
         hasNextPage
       }
     }
   }
   ```

   - Get the first 5 users:

   ```graphql
   query {
     users(first: 5) {
       totalCount
       edges {
         node {
           id
           name
           email
         }
         cursor
       }
       pageInfo {
         endCursor
         hasNextPage
       }
     }
   }
   ```

   - Get the users after a specific cursor:

   ```graphql
   query {
     users(after: "<cursor_value>") {
       totalCount
       edges {
         node {
           id
           name
           email
         }
         cursor
       }
       pageInfo {
         endCursor
         hasNextPage
       }
     }
   }
   ```

   Replace `<cursor_value>` with the actual cursor value obtained from a previous query.

   - Get the next 5 users after a specific cursor:

   ```graphql
   query {
     users(first: 5, after: "<cursor_value>") {
       totalCount
       edges {
         node {
           id
           name
           email
         }
         cursor
       }
       pageInfo {
         endCursor
         hasNextPage
       }
     }
   }
   ```

   Replace `<cursor_value>` with the actual cursor value obtained from a previous query.

3. You can modify and execute these queries in the GraphiQL interface to interact with the GraphQL server and see the paginated results.

### Congratulations!

You have successfully set up and run the GraphQL Pagination Example project. You can now explore and test the pagination functionality using the provided GraphQL queries.
