// src/resolvers/userResolvers.js

// Fetch users from your data source
const allUsers = require("../datasource/usersData");

const getUsers = (first, after) => {
  // Apply pagination logic based on 'first' and 'after' arguments
  // Return the paginated results

  // Apply pagination
  let users = allUsers.slice(); // Copy the array
  if (after) {
    const startIndex = users.findIndex((user) => user.id === after);
    users = users.slice(startIndex + 1);
  }
  if (first) {
    users = users.slice(0, first);
  }

  const edges = users.map((user) => ({
    node: user,
    cursor: user.id
  }));

  const hasNextPage = allUsers.length > users.length + (after ? 1 : 0);
  const endCursor = users.length > 0 ? users[users.length - 1].id : null;
  const startCursor = users.length > 0 ? users[0].id : null;

  console.log("Paginated users:", users); // Log the paginated users

  const pageInfo = {
    totalCount: allUsers.length,
    endCursor,
    hasNextPage,
    startCursor
  };

  console.log("Page info:", pageInfo); // Log the page info

  return {
    edges,
    pageInfo
  };
};

const userResolvers = {
  users: ({ first, after }) => getUsers(first, after)
};

module.exports = userResolvers;
